==> haskell-th-compat-0.1.5-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-compat
version:              0.1.5
visibility:           public
id:                   th-compat-0.1.5-DGDHQ3zg5lpAWsPNoCEdRG
key:                  th-compat-0.1.5-DGDHQ3zg5lpAWsPNoCEdRG
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  0f53bd4e3f111a544ceb6c02d7f00e8c
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.5-DGDHQ3zg5lpAWsPNoCEdRG
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-compat-0.1.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-compat
version:              0.1.6
visibility:           public
id:                   th-compat-0.1.6-4oe2nIahlu72vkc42MDQZC
key:                  th-compat-0.1.6-4oe2nIahlu72vkc42MDQZC
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  f7a397386ed58779c4e8e8631fa1028e
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.6-4oe2nIahlu72vkc42MDQZC
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
